Administrator's Guide
=====================

Installation & Operations
-------------------------

If you are a system administrator running Magnum, this section contains
information that should help you understand how to deploy, operate, and upgrade
the services.

.. toctree::
  :maxdepth: 1

  Magnum Proxy <magnum-proxy>
  gmr
  Troubleshooting FAQ <troubleshooting-guide>

Configuration
-------------

Following pages will be helpful in configuring specific aspects
of Magnum that may or may not be suitable to every situation.

.. toctree::
  :maxdepth: 1

  configuring
